import React from 'react';
import { message, Modal } from 'antd';
import { push } from '../services/route';
import { errors as errorCodes } from './config';

const errStyle = {
  overflow: 'auto',
  wordWrap: 'break-word',
  width: '360px',
  height: '360px',
  marginLeft: '-24px',
  marginTop: '24px',
};

export function processError(err) {
  if (err && err.data) {
    const data = err.data;
    switch (data.errorCode) {
      case errorCodes.no_such_user:
        message.error('用户不存在！');
        break;
      case errorCodes.invalid_token:
        push('/login');
        break;
      default:
        showError(err);
    }
  }
}

function showError(err) {
  if (err) {
    let msg;
    if (err.data) {
      const data = err.data;
      msg = data ? data.message : err.message;
    } else {
      msg = err.message;
    }
    if (msg && msg.length < 256) {
      message.error(msg);
    } else {
      Modal.error({
        title: '服务器内部错误',
        content: <div style={errStyle}>{msg}</div>,
        width: 460,
      });
    }
  }
}

export function createError({ code, msg }) {
  const error = new Error(msg);
  error.data = {
    errorCode: code,
    message: msg,
  };
  return error;
}

export const errors = {
  tokenMissing: () => createError({
    code: errorCodes.token_missing,
    msg: '需要登录！',
  }),
  wrongPassword: () => createError({
    code: errorCodes.wrong_password,
    msg: '密码错误！',
  }),
  unsupportedAuthType: (...types) => createError({
    code: errorCodes.unsupported_auth_type,
    msg: `不支持的客户端验证方式：${types.join('、')}.`,
  }),
};
